@@ -16,7 +16,6 @@
 __docformat__ = "restructuredtext"
 
 # import standard packages
-from datetime import datetime
 from persistent import Persistent
 from persistent.list import PersistentList
 
@@ -25,24 +24,22 @@ from zope.annotation.interfaces import IAnnotations
 from zope.dublincore.interfaces import IZopeDublinCore
 
 # import local interfaces
-from interfaces import IComment, IComments, ICommentsList, ICommentable
-from interfaces import ICommentAddedEvent
+from ztfy.comment.interfaces import IComment, IComments, ICommentsList, ICommentable
+from ztfy.comment.interfaces import ICommentAddedEvent
 
 # import Zope3 packages
 from zope.component import adapts
 from zope.event import notify
-from zope.i18n import translate
 from zope.interface import implements
+from zope.location import Location, locate
 from zope.lifecycleevent import ObjectCreatedEvent, ObjectModifiedEvent
 
 # import local packages
 from ztfy.security.search import getPrincipal
+from ztfy.utils.date import getAge
 from ztfy.utils.request import getRequest
 from ztfy.utils.security import unproxied
 from ztfy.utils.text import textToHTML
-from ztfy.utils.timezone import gmtime
-
-from ztfy.comment import _
 
 
 class CommentAddedEvent(ObjectModifiedEvent):
@@ -54,7 +51,7 @@ class CommentAddedEvent(ObjectModifiedEvent):
         self.comment = comment
 
 
-class Comment(Persistent):
+class Comment(Persistent, Location):
 
     implements(IComment)
 
@@ -71,26 +68,7 @@ class Comment(Persistent):
         return IZopeDublinCore(self).created
 
     def getAge(self):
-        now = gmtime(datetime.utcnow())
-        delta = now - self.date
-        if delta.days > 60:
-            return translate(_("%d months ago")) % int(round(delta.days * 1.0 / 30))
-        elif delta.days > 10:
-            return translate(_("%d weeks ago")) % int(round(delta.days * 1.0 / 7))
-        elif delta.days > 2:
-            return translate(_("%d days ago")) % delta.days
-        elif delta.days == 2:
-            return translate(_("the day before yesterday"))
-        elif delta.days == 1:
-            return translate(_("yesterday"))
-        else:
-            hours = int(round(delta.seconds * 1.0 / 3600))
-            if hours > 1:
-                return translate(_("%d hours ago")) % hours
-            elif delta.seconds > 300:
-                return translate(_("%d minutes ago")) % int(round(delta.seconds * 1.0 / 60))
-            else:
-                return translate(_("less than 5 minutes ago"))
+        return getAge(self.date)
 
     @property
     def principal_id(self):
@@ -111,6 +89,10 @@ class Comments(PersistentList):
 
     implements(ICommentsList)
 
+    def append(self, item):
+        super(Comments, self).append(item)
+        locate(item, self)
+
 
 COMMENTS_ANNOTATION_KEY = 'ztfy.comment'
 
@@ -125,6 +107,7 @@ class CommentsAdapter(object):
         comments = annotations.get(COMMENTS_ANNOTATION_KEY)
         if comments is None:
             comments = annotations[COMMENTS_ANNOTATION_KEY] = Comments()
+            locate(comments, self.context)
         self.comments = comments
 
     def getComments(self, tag=None):
