@@ -19,7 +19,7 @@ __docformat__ = "restructuredtext"
 
 # import Zope3 interfaces
 from zope.annotation.interfaces import IAttributeAnnotatable
-from zope.app.security.interfaces import IPrincipal
+from zope.security.interfaces import IPrincipal
 
 # import local interfaces
 
@@ -65,8 +65,9 @@ class IComment(ICommentable):
 
     body_renderer = Choice(title=_("Comment renderer"),
                            description=_("Name of utility used to render comment's body"),
-                           required=False,
-                           vocabulary='SourceTypes')
+                           required=True,
+                           vocabulary='SourceTypes',
+                           default=u'zope.source.plaintext')
 
     in_reply_to = Object(title=_("Comment's parent"),
                          description=_("Previous comment to which this comment replies"),
